@@ -15,7 +15,8 @@ import time
     device='TEV0217315000851',      # android device id or iOS udid
     file_path='./demo1.mp4',        # mp4 file path
     offset=(1, 1),                  # default (1, 1), mean of: before record sleep 1s and after record sleep 1s
-    pre_kill=True                   # default True, before start whether kill or not
+    pre_kill=True,                  # default True, before start whether kill or not
+    high_dfn=False
 )
 def android_case(t: int):
     for i in range(t):
@@ -27,10 +28,10 @@ def android_case(t: int):
     platform='ios',                         # 'i', 'ios'
     device='00008020-001D1D900CB9002E',     # iOS UDID
     file_path='./demo2.mp4',                # video file path
-    offset=(2, 1),                          # same as android
+    offset=(0.5, 1),                        # same as android
     pre_kill=True,                          # same as android
-    xrecord='./xrecord'                     # xrecord file path, iOS required fields,
                                             # Refs: https://github.com/WPO-Foundation/xrecord
+    high_dfn=False
 )
 def ios_case(t: int):
     for i in range(t):
