@@ -6,7 +6,7 @@ __AUTHOR__ = r"ssfanli"
 __AUTHOR_EMAIL__ = r"freedomlidi@163.com"
 __LICENSE__ = r"MIT"
 __URL__ = r"https://github.com/ssfanli/screcord.git"
-__VERSION__ = r"0.0.5"
+__VERSION__ = r"0.0.8"
 __DESCRIPTION__ = r"A python wrapper for Android/iOS screen recording."
 
 import typing
@@ -91,16 +91,29 @@ def kill(process_name: str):
         logger.info(f'=== KILL PROCESS: {process_name} ===')
 
 
-def _cmd(platform: str, **kwargs):
+def xrecord_path():
+    return os.path.join(os.path.dirname(__file__), 'xrecord')
+
+
+def _cmd(platform: str,  high_dfn: bool, **kwargs):
     """build cmd according to platform
     """
     platform = platform.lower()
     assert platform in ('a', 'android', 'i', 'ios'), f"platform should in ('a', 'android', 'i', 'ios')"
     if platform in ('a', 'android'):
-        cmd = 'scrcpy -s "{device}" --render-expired-frames -Nr "{fp}"'.format(**kwargs)
+        if high_dfn:
+            cmd_str = 'scrcpy -s "{device}" --render-expired-frames -Nr "{fp}"'
+        else:
+            cmd_str = 'scrcpy -s "{device}" -Nr "{fp}"'
+        cmd = cmd_str.format(**kwargs)
         proc_name = 'scrcpy'
     else:
-        cmd = '"{xrecord}" -q -i="{device}" -o="{fp}" -f'.format(**kwargs)
+        if high_dfn:
+            cmd_str = '"{xrecord}" -q -i "{device}" -o "{fp}" -f'
+        else:
+            cmd_str = '"{xrecord}" -q -i "{device}" -o "{fp}" -u medium -f'
+        kwargs['xrecord'] = xrecord_path()
+        cmd = cmd_str.format(**kwargs)
         proc_name = 'xrecord'
     logger.info(
         f'\n===== CMD INFO ====='
@@ -112,10 +125,7 @@ def _cmd(platform: str, **kwargs):
     return proc_name, cmd
 
 
-def _update_offset(
-    offset: typing.Union[typing.Tuple[int], typing.Tuple[int, int]]
-):
-
+def _update_offset(offset):
     assert isinstance(offset, tuple), 'offset type should be tuple'
     assert len(offset) <= 2, 'len(offset) should <= 2'
     offset = offset or (1, 1)
@@ -124,14 +134,12 @@ def _update_offset(
     return offset
 
 
-def record(
-        platform: typing.Union[str],
-        device: typing.Union[str],
-        file_path: typing.Union[str, os.PathLike],
-        offset: typing.Tuple[int] = (1, 1),
-        pre_kill: typing.Union[bool] = True,
-        xrecord: typing.Union[str, os.PathLike] = None
-):
+def record(platform: str, device: str,
+           file_path: typing.Union[str, os.PathLike],
+           offset: tuple = (1, 1),
+           pre_kill: bool = True,
+           high_dfn: bool = True
+           ):
     """record wrapper
 
     platform: 'a', 'android', 'i', 'ios'
@@ -139,13 +147,14 @@ def record(
     file_path: mp4 file path
     offset: default (1, 1), mean of: before record sleep 1s and after record sleep 1s
     pre_kill: before start whether kill or not, default True
-    xrecord: xrecord file path
+    high_dfn: record video in high definition
     """
+
     def decorator(func):
         @functools.wraps(func)
         def wrapper(*args, **kwargs):
             ofs = _update_offset(offset)
-            proc_name, cmd = _cmd(platform, device=device, fp=file_path, xrecord=xrecord)
+            proc_name, cmd = _cmd(platform, high_dfn, device=device, fp=file_path)
             p = start(proc_name, cmd, pre_kill)
             try:
                 time.sleep(ofs[0])
@@ -155,7 +164,11 @@ def record(
                 logger.error(e)
             finally:
                 stop(proc_name, p)
+
         return wrapper
+
     return decorator
 
 
+if __name__ == '__main__':
+    print(xrecord_path())
